import type { TypeOf, z } from 'zod';
import type { EventRegistry } from '../events/EventRegistry';
import type { PublisherBaseEventType } from '../events/baseEventSchemas';
import type { CommonEventDefinition } from '../events/eventTypes';
import type { MetadataFiller } from '../messages/MetadataFiller';
import type { AsyncPublisher, SyncPublisher } from '../types/MessageQueueTypes';
import type { CommonCreationConfigType, QueuePublisherOptions } from '../types/queueOptionsTypes';
import type { PublicHandlerSpy } from './HandlerSpy';
export type MessagePublishType<T extends CommonEventDefinition> = z.infer<T['publisherSchema']>;
export type MessageSchemaType<T extends CommonEventDefinition> = z.infer<T['consumerSchema']>;
export type AbstractPublisherFactory<PublisherType extends AsyncPublisher<object, unknown> | SyncPublisher<object, unknown>, DependenciesType, CreationConfigType extends CommonCreationConfigType, QueueLocatorType extends object, EventType extends PublisherBaseEventType, OptionsType extends Omit<QueuePublisherOptions<CreationConfigType, QueueLocatorType, EventType>, 'messageSchemas' | 'creationConfig' | 'locatorConfig'>> = {
    buildPublisher(dependencies: DependenciesType, options: OptionsType): PublisherType;
};
export declare abstract class AbstractPublisherManager<EventDefinitionType extends CommonEventDefinition, EventTargets extends string, PublisherType extends AsyncPublisher<object, unknown> | SyncPublisher<object, unknown>, DependenciesType, CreationConfigType extends CommonCreationConfigType, QueueLocatorType extends object, EventType extends PublisherBaseEventType, OptionsType extends Omit<QueuePublisherOptions<CreationConfigType, QueueLocatorType, EventType>, 'messageSchemas' | 'creationConfig' | 'locatorConfig'>, SupportedEventDefinitions extends EventDefinitionType[], MetadataType, MessageOptionsType> {
    private readonly publisherFactory;
    protected readonly newPublisherOptions: OptionsType;
    protected readonly metadataFiller: MetadataFiller<z.infer<SupportedEventDefinitions[number]['consumerSchema']>, MetadataType>;
    protected readonly metadataField: string;
    protected readonly targetToEventMap: Record<EventTargets, EventDefinitionType[]>;
    protected readonly isAsync: boolean;
    protected targetToPublisherMap: Record<EventTargets, PublisherType>;
    private readonly publisherDependencies;
    protected constructor({ publisherFactory, newPublisherOptions, publisherDependencies, metadataFiller, eventRegistry, metadataField, isAsync, }: {
        publisherFactory: AbstractPublisherFactory<PublisherType, DependenciesType, CreationConfigType, QueueLocatorType, EventType, OptionsType>;
        newPublisherOptions: OptionsType;
        publisherDependencies: DependenciesType;
        metadataFiller: MetadataFiller<TypeOf<SupportedEventDefinitions[number]['consumerSchema']>, MetadataType>;
        eventRegistry: EventRegistry<SupportedEventDefinitions>;
        metadataField: string;
        isAsync: boolean;
    });
    protected abstract resolveEventTarget(event: EventDefinitionType): EventTargets | undefined;
    protected abstract resolveCreationConfig(eventTarget: string): CreationConfigType;
    protected resolvePublisherConfigOverrides(_eventTarget: string): Partial<OptionsType>;
    private registerEvents;
    private registerPublishers;
    injectPublisher(eventTarget: EventTargets, publisher: PublisherType): void;
    injectEventDefinition(eventDefinition: EventDefinitionType): void;
    publish(eventTarget: EventTargets, message: MessagePublishType<SupportedEventDefinitions[number]>, precedingEventMetadata?: Partial<MetadataType>, messageOptions?: MessageOptionsType): Promise<MessageSchemaType<SupportedEventDefinitions[number]>>;
    protected resolveMessageDefinition(eventTarget: EventTargets, message: MessagePublishType<SupportedEventDefinitions[number]>): EventDefinitionType | undefined;
    protected resolveMessage(messageDefinition: EventDefinitionType | undefined, message: MessagePublishType<SupportedEventDefinitions[number]>, precedingEventMetadata?: Partial<MetadataType>): MessageSchemaType<SupportedEventDefinitions[number]>;
    resolveBaseFields(): {
        id: string;
        timestamp: string;
    };
    /**
     * @param eventTarget - topic or exchange
     */
    handlerSpy(eventTarget: EventTargets): PublicHandlerSpy<object>;
}
