"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HandlerContainer = exports.MessageHandlerConfigBuilder = exports.MessageHandlerConfig = exports.defaultLogFormatter = void 0;
const schemas_1 = require("@message-queue-toolkit/schemas");
const defaultLogFormatter = (message) => message;
exports.defaultLogFormatter = defaultLogFormatter;
class MessageHandlerConfig {
    schema;
    definition;
    handler;
    messageLogFormatter;
    preHandlerBarrier;
    preHandlers;
    constructor(schema, handler, options, eventDefinition) {
        this.schema = schema;
        this.definition = eventDefinition;
        this.handler = handler;
        this.messageLogFormatter = options?.messageLogFormatter ?? exports.defaultLogFormatter;
        this.preHandlerBarrier = options?.preHandlerBarrier;
        this.preHandlers = options?.preHandlers ?? [];
    }
}
exports.MessageHandlerConfig = MessageHandlerConfig;
class MessageHandlerConfigBuilder {
    configs;
    constructor() {
        this.configs = [];
    }
    addConfig(schema, handler, options) {
        const resolvedSchema = (0, schemas_1.isCommonEventDefinition)(schema)
            ? // @ts-ignore
                schema.consumerSchema
            : schema;
        const definition = (0, schemas_1.isCommonEventDefinition)(schema) ? schema : undefined;
        this.configs.push(
        // @ts-ignore
        new MessageHandlerConfig(resolvedSchema, 
        // @ts-ignore
        handler, options, definition));
        return this;
    }
    build() {
        return this.configs;
    }
}
exports.MessageHandlerConfigBuilder = MessageHandlerConfigBuilder;
class HandlerContainer {
    messageHandlers;
    messageTypeField;
    constructor(options) {
        this.messageTypeField = options.messageTypeField;
        this.messageHandlers = this.resolveHandlerMap(options.messageHandlers);
    }
    resolveHandler(messageType) {
        const handler = this.messageHandlers[messageType];
        if (!handler) {
            throw new Error(`Unsupported message type: ${messageType}`);
        }
        // @ts-ignore
        // eslint-disable-next-line @typescript-eslint/no-unsafe-return
        return handler;
    }
    resolveHandlerMap(supportedHandlers) {
        return supportedHandlers.reduce((acc, entry) => {
            // @ts-ignore
            const messageType = entry.schema.shape[this.messageTypeField].value;
            // @ts-ignore
            acc[messageType] = entry;
            return acc;
        }, {});
    }
}
exports.HandlerContainer = HandlerContainer;
//# sourceMappingURL=HandlerContainer.js.map