import type { ErrorReporter, ErrorResolver } from '@lokalise/node-core';
import type { ZodSchema } from 'zod';
import type { PayloadStoreConfig } from '../payload-store/payloadStoreTypes';
import type { MessageHandlerConfig } from '../queues/HandlerContainer';
import type { HandlerSpy, HandlerSpyParams } from '../queues/HandlerSpy';
import type { Logger, TransactionObservabilityManager } from './MessageQueueTypes';
export type QueueDependencies = {
    errorReporter: ErrorReporter;
    logger: Logger;
};
export type QueueConsumerDependencies = {
    consumerErrorResolver: ErrorResolver;
    transactionObservabilityManager: TransactionObservabilityManager;
};
export type CommonQueueOptions = {
    messageTypeField: string;
    messageIdField?: string;
    messageTimestampField?: string;
    handlerSpy?: HandlerSpy<object> | HandlerSpyParams | boolean;
    logMessages?: boolean;
    deletionConfig?: DeletionConfig;
    payloadStoreConfig?: PayloadStoreConfig;
};
export type CommonCreationConfigType = {
    updateAttributesIfExists?: boolean;
};
export type DeletionConfig = {
    deleteIfExists?: boolean;
    waitForConfirmation?: boolean;
    forceDeleteInProduction?: boolean;
};
type NewQueueOptions<CreationConfigType extends CommonCreationConfigType> = {
    locatorConfig?: never;
    creationConfig: CreationConfigType;
};
type ExistingQueueOptions<QueueLocatorType extends object> = {
    locatorConfig: QueueLocatorType;
    creationConfig?: never;
};
export type QueueOptions<CreationConfigType extends CommonCreationConfigType, QueueLocatorType extends object> = CommonQueueOptions & (NewQueueOptions<CreationConfigType> | ExistingQueueOptions<QueueLocatorType>);
export type QueuePublisherOptions<CreationConfigType extends CommonCreationConfigType, QueueLocatorType extends object, MessagePayloadSchemas extends object> = QueueOptions<CreationConfigType, QueueLocatorType> & {
    messageSchemas: readonly ZodSchema<MessagePayloadSchemas>[];
};
export type DeadLetterQueueOptions<CreationConfigType extends object, QueueLocatorType extends object, DeadLetterQueueIntegrationOptions extends object> = {
    deletionConfig?: DeletionConfig;
} & DeadLetterQueueIntegrationOptions & (NewQueueOptions<CreationConfigType> | ExistingQueueOptions<QueueLocatorType>);
export type QueueConsumerOptions<CreationConfigType extends object, QueueLocatorType extends object, DeadLetterQueueIntegrationOptions extends object, MessagePayloadSchemas extends object, ExecutionContext, PrehandlerOutput = undefined, DeadLetterQueueCreationConfigType extends object = CreationConfigType, DeadLetterQueueQueueLocatorType extends object = QueueLocatorType> = QueueOptions<CreationConfigType, QueueLocatorType> & {
    handlers: MessageHandlerConfig<MessagePayloadSchemas, ExecutionContext, PrehandlerOutput>[];
    deadLetterQueue?: DeadLetterQueueOptions<DeadLetterQueueCreationConfigType, DeadLetterQueueQueueLocatorType, DeadLetterQueueIntegrationOptions>;
    maxRetryDuration?: number;
};
export {};
